==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scvmm/kotlin/inputs/HttpProxyConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scvmm.kotlin.inputs

import com.pulumi.azurenative.scvmm.inputs.HttpProxyConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * HTTP Proxy configuration for the VM.
 * @property httpsProxy Gets or sets httpsProxy url.
 */
public data class HttpProxyConfigurationArgs(
    public val httpsProxy: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scvmm.inputs.HttpProxyConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.scvmm.inputs.HttpProxyConfigurationArgs =
        com.pulumi.azurenative.scvmm.inputs.HttpProxyConfigurationArgs.builder()
            .httpsProxy(httpsProxy?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpProxyConfigurationArgs].
 */
@PulumiTagMarker
public class HttpProxyConfigurationArgsBuilder internal constructor() {
    private var httpsProxy: Output<String>? = null

    /**
     * @param value Gets or sets httpsProxy url.
     */
    @JvmName("ttxwmeoisxcqsfud")
    public suspend fun httpsProxy(`value`: Output<String>) {
        this.httpsProxy = value
    }

    /**
     * @param value Gets or sets httpsProxy url.
     */
    @JvmName("ywnsaghptawnbmvl")
    public suspend fun httpsProxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpsProxy = mapped
    }

    internal fun build(): HttpProxyConfigurationArgs = HttpProxyConfigurationArgs(
        httpsProxy = httpsProxy,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scvmm/kotlin/inputs/HttpProxyConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scvmm.kotlin.inputs

import com.pulumi.azurenative.scvmm.inputs.HttpProxyConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * HTTP Proxy configuration for the VM.
 * @property httpsProxy Gets or sets httpsProxy url.
 */
public data class HttpProxyConfigurationArgs(
    public val httpsProxy: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scvmm.inputs.HttpProxyConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.scvmm.inputs.HttpProxyConfigurationArgs =
        com.pulumi.azurenative.scvmm.inputs.HttpProxyConfigurationArgs.builder()
            .httpsProxy(httpsProxy?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpProxyConfigurationArgs].
 */
@PulumiTagMarker
public class HttpProxyConfigurationArgsBuilder internal constructor() {
    private var httpsProxy: Output<String>? = null

    /**
     * @param value Gets or sets httpsProxy url.
     */
    @JvmName("ujskfvcitepelylt")
    public suspend fun httpsProxy(`value`: Output<String>) {
        this.httpsProxy = value
    }

    /**
     * @param value Gets or sets httpsProxy url.
     */
    @JvmName("ysdcfacoyxgwjbcd")
    public suspend fun httpsProxy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.httpsProxy = mapped
    }

    internal fun build(): HttpProxyConfigurationArgs = HttpProxyConfigurationArgs(
        httpsProxy = httpsProxy,
    )
}
